Class: Aws::IAMToolbox::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IAMToolbox::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iamtoolbox/client.rb,
sig/client.rbs
Overview
An API client for IAMToolbox. To construct a client, you need to configure a :region and :credentials.
client = Aws::IAMToolbox::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetRequestAuthorizationDetailsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_request_authorization_details(params = {}) ⇒ Types::GetRequestAuthorizationDetailsOutput
Retrieves the authorization details for a specific access denied request.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iamtoolbox/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
576 577 578 |
# File 'lib/aws-sdk-iamtoolbox/client.rb', line 576 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
579 580 581 |
# File 'lib/aws-sdk-iamtoolbox/client.rb', line 579 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iamtoolbox/client.rb', line 549 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IAMToolbox') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iamtoolbox' context[:gem_version] = '1.0.0' Seahorse::Client::Request.new(handlers, context) end |
#get_request_authorization_details(params = {}) ⇒ Types::GetRequestAuthorizationDetailsOutput
Retrieves the authorization details for a specific access denied request. The details include the request context, the evaluations performed, and the policies that were evaluated.
Use this operation to understand why a request was denied. Supported services include an authorization ID in the access denied error message. Pass that ID to this operation to retrieve the details.
Authorization details are available for at least 24 hours after the denial.
To use this operation, you must have the
iam:GetRequestAuthorizationDetails permission.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
89 |
# File 'sig/client.rbs', line 89
def get_request_authorization_details: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
569 570 571 |
# File 'lib/aws-sdk-iamtoolbox/client.rb', line 569 def waiter_names [] end |