Module: Aws::IAMToolbox::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-iamtoolbox/errors.rb,
sig/errors.rbs
Overview
When IAMToolbox returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::IAMToolbox::Errors::ServiceError < Errors::ServiceError
You can rescue all IAMToolbox errors using ServiceError:
begin
# do stuff
rescue Aws::IAMToolbox::Errors::ServiceError
# rescues all IAMToolbox API errors
end
Request Context
ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, InternalServerException, ResourceNotFoundException, ServiceError, ValidationException