Class: Aws::IAMToolbox::Types::AttachedTo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iamtoolbox/types.rb

Overview

An entity that a policy is attached to, identified by its ARN.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the entity that the policy is attached to. The ARN format depends on the policy type:

  • For identity, session, and permissions boundary policies, this is the principal ARN (for example, an IAM role or user ARN).

  • For resource-based policies, this is the resource ARN.

  • For organization control policies (SCPs and RCPs), this is the AWS Organizations ARN of the account, organizational unit, or root.

Returns:

  • (String)


43
44
45
46
47
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 43

class AttachedTo < Struct.new(
  :arn)
  SENSITIVE = []
  include Aws::Structure
end