Class: Aws::IAMToolbox::Types::Evaluation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iamtoolbox/types.rb

Overview

Represents an individual evaluation for a single action and resource pair. This includes the context, the resulting effect, and any policies that matched.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action evaluated for this request (for example, iam:PassRole).

Returns:

  • (String)


86
87
88
89
90
91
92
93
94
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86

class Evaluation < Struct.new(
  :action,
  :resource,
  :context,
  :evaluated_effect,
  :matched_policies)
  SENSITIVE = []
  include Aws::Structure
end

#contextHash<String,Hash,Array,String,Numeric,Boolean>

The context keys and values specific to this evaluation. These are applied on top of the request context.

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


86
87
88
89
90
91
92
93
94
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86

class Evaluation < Struct.new(
  :action,
  :resource,
  :context,
  :evaluated_effect,
  :matched_policies)
  SENSITIVE = []
  include Aws::Structure
end

#evaluated_effectString

The result of the evaluation. Valid values:

  • ALLOW - The action was allowed.

  • EXPLICIT_DENY - The action was explicitly denied by a policy.

  • IMPLICIT_DENY - The action was denied because no policy allowed it.

Returns:

  • (String)


86
87
88
89
90
91
92
93
94
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86

class Evaluation < Struct.new(
  :action,
  :resource,
  :context,
  :evaluated_effect,
  :matched_policies)
  SENSITIVE = []
  include Aws::Structure
end

#matched_policiesArray<Types::MatchedPolicy>

The policies that matched during evaluation of this action and resource. An implicit denial produces no matched policies.

Returns:



86
87
88
89
90
91
92
93
94
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86

class Evaluation < Struct.new(
  :action,
  :resource,
  :context,
  :evaluated_effect,
  :matched_policies)
  SENSITIVE = []
  include Aws::Structure
end

#resourceString

The resource that the action targeted. This is typically a resource ARN, but can be a wildcard ARN that matches multiple resources, or empty for actions that are not resource-specific.

Returns:

  • (String)


86
87
88
89
90
91
92
93
94
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86

class Evaluation < Struct.new(
  :action,
  :resource,
  :context,
  :evaluated_effect,
  :matched_policies)
  SENSITIVE = []
  include Aws::Structure
end