Class: Aws::IAMToolbox::Types::GetRequestAuthorizationDetailsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAMToolbox::Types::GetRequestAuthorizationDetailsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iamtoolbox/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorization_id ⇒ String
The authorization ID received in the access denied error message.
-
#next_token ⇒ String
The pagination token from a previous call, used to retrieve the next page of evaluations.
Instance Attribute Details
#authorization_id ⇒ String
The authorization ID received in the access denied error message. This ID identifies the specific request to retrieve details for.
108 109 110 111 112 113 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 108 class GetRequestAuthorizationDetailsInput < Struct.new( :authorization_id, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from a previous call, used to retrieve the next page of evaluations. Omit this value on the first call.
108 109 110 111 112 113 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 108 class GetRequestAuthorizationDetailsInput < Struct.new( :authorization_id, :next_token) SENSITIVE = [] include Aws::Structure end |