Class: Aws::IAMToolbox::Types::GetRequestAuthorizationDetailsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iamtoolbox/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#evaluationsArray<Types::Evaluation>

The list of evaluations for this request. Each evaluation shows how a single action and resource pair was evaluated. This includes the context, the effect, and any policies that matched.

Returns:



137
138
139
140
141
142
143
144
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137

class GetRequestAuthorizationDetailsOutput < Struct.new(
  :request_context,
  :evaluations,
  :policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token for retrieving the next page of evaluations. This value is absent when there are no more results.

Returns:

  • (String)


137
138
139
140
141
142
143
144
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137

class GetRequestAuthorizationDetailsOutput < Struct.new(
  :request_context,
  :evaluations,
  :policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#policiesArray<Types::PolicyInfo>

The list of policies that were evaluated.

Returns:



137
138
139
140
141
142
143
144
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137

class GetRequestAuthorizationDetailsOutput < Struct.new(
  :request_context,
  :evaluations,
  :policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#request_contextHash<String,Hash,Array,String,Numeric,Boolean>

The request context is the set of context keys and values that apply to the entire request and are shared by all evaluations.

Returns:

  • (Hash<String,Hash,Array,String,Numeric,Boolean>)


137
138
139
140
141
142
143
144
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137

class GetRequestAuthorizationDetailsOutput < Struct.new(
  :request_context,
  :evaluations,
  :policies,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end