Class: Aws::IAMToolbox::Types::MatchedPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iamtoolbox/types.rb

Overview

A policy that matched during evaluation, referenced by URI. The URI corresponds to a policy in the top-level policies list.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#matched_statementsArray<Types::MatchedStatement>

The statements within the policy that matched during the evaluation.

Returns:



177
178
179
180
181
182
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 177

class MatchedPolicy < Struct.new(
  :uri,
  :matched_statements)
  SENSITIVE = []
  include Aws::Structure
end

#uriString

The URI of the policy. This cross-references an entry in the top-level policies list. The value depends on the policy type:

  • For managed policies, this is the policy ARN.

  • For inline policies, this is an opaque identifier.

Returns:

  • (String)


177
178
179
180
181
182
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 177

class MatchedPolicy < Struct.new(
  :uri,
  :matched_statements)
  SENSITIVE = []
  include Aws::Structure
end