Class: Aws::IAMToolbox::Types::Evaluation
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAMToolbox::Types::Evaluation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iamtoolbox/types.rb
Overview
Represents an individual evaluation for a single action and resource pair. This includes the context, the resulting effect, and any policies that matched.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action evaluated for this request (for example,
iam:PassRole). -
#context ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
The context keys and values specific to this evaluation.
-
#evaluated_effect ⇒ String
The result of the evaluation.
-
#matched_policies ⇒ Array<Types::MatchedPolicy>
The policies that matched during evaluation of this action and resource.
-
#resource ⇒ String
The resource that the action targeted.
Instance Attribute Details
#action ⇒ String
The action evaluated for this request (for example, iam:PassRole).
86 87 88 89 90 91 92 93 94 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86 class Evaluation < Struct.new( :action, :resource, :context, :evaluated_effect, :matched_policies) SENSITIVE = [] include Aws::Structure end |
#context ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
The context keys and values specific to this evaluation. These are applied on top of the request context.
86 87 88 89 90 91 92 93 94 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86 class Evaluation < Struct.new( :action, :resource, :context, :evaluated_effect, :matched_policies) SENSITIVE = [] include Aws::Structure end |
#evaluated_effect ⇒ String
The result of the evaluation. Valid values:
-
ALLOW- The action was allowed. -
EXPLICIT_DENY- The action was explicitly denied by a policy. -
IMPLICIT_DENY- The action was denied because no policy allowed it.
86 87 88 89 90 91 92 93 94 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86 class Evaluation < Struct.new( :action, :resource, :context, :evaluated_effect, :matched_policies) SENSITIVE = [] include Aws::Structure end |
#matched_policies ⇒ Array<Types::MatchedPolicy>
The policies that matched during evaluation of this action and resource. An implicit denial produces no matched policies.
86 87 88 89 90 91 92 93 94 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86 class Evaluation < Struct.new( :action, :resource, :context, :evaluated_effect, :matched_policies) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ String
The resource that the action targeted. This is typically a resource ARN, but can be a wildcard ARN that matches multiple resources, or empty for actions that are not resource-specific.
86 87 88 89 90 91 92 93 94 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 86 class Evaluation < Struct.new( :action, :resource, :context, :evaluated_effect, :matched_policies) SENSITIVE = [] include Aws::Structure end |