Class: Aws::IAMToolbox::Types::GetRequestAuthorizationDetailsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAMToolbox::Types::GetRequestAuthorizationDetailsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iamtoolbox/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluations ⇒ Array<Types::Evaluation>
The list of evaluations for this request.
-
#next_token ⇒ String
The pagination token for retrieving the next page of evaluations.
-
#policies ⇒ Array<Types::PolicyInfo>
The list of policies that were evaluated.
-
#request_context ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
The request context is the set of context keys and values that apply to the entire request and are shared by all evaluations.
Instance Attribute Details
#evaluations ⇒ Array<Types::Evaluation>
The list of evaluations for this request. Each evaluation shows how a single action and resource pair was evaluated. This includes the context, the effect, and any policies that matched.
137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137 class GetRequestAuthorizationDetailsOutput < Struct.new( :request_context, :evaluations, :policies, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for retrieving the next page of evaluations. This value is absent when there are no more results.
137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137 class GetRequestAuthorizationDetailsOutput < Struct.new( :request_context, :evaluations, :policies, :next_token) SENSITIVE = [] include Aws::Structure end |
#policies ⇒ Array<Types::PolicyInfo>
The list of policies that were evaluated.
137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137 class GetRequestAuthorizationDetailsOutput < Struct.new( :request_context, :evaluations, :policies, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_context ⇒ Hash<String,Hash,Array,String,Numeric,Boolean>
The request context is the set of context keys and values that apply to the entire request and are shared by all evaluations.
137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 137 class GetRequestAuthorizationDetailsOutput < Struct.new( :request_context, :evaluations, :policies, :next_token) SENSITIVE = [] include Aws::Structure end |