Class: Aws::IAMToolbox::Types::MatchedPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAMToolbox::Types::MatchedPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iamtoolbox/types.rb
Overview
A policy that matched during evaluation, referenced by URI. The URI corresponds to a policy in the top-level policies list.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#matched_statements ⇒ Array<Types::MatchedStatement>
The statements within the policy that matched during the evaluation.
-
#uri ⇒ String
The URI of the policy.
Instance Attribute Details
#matched_statements ⇒ Array<Types::MatchedStatement>
The statements within the policy that matched during the evaluation.
177 178 179 180 181 182 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 177 class MatchedPolicy < Struct.new( :uri, :matched_statements) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The URI of the policy. This cross-references an entry in the top-level policies list. The value depends on the policy type:
-
For managed policies, this is the policy ARN.
-
For inline policies, this is an opaque identifier.
177 178 179 180 181 182 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 177 class MatchedPolicy < Struct.new( :uri, :matched_statements) SENSITIVE = [] include Aws::Structure end |