Class: Aws::IAMToolbox::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IAMToolbox::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iamtoolbox/types.rb
Overview
The requested authorization details do not exist in this region or have expired. Verify that the authorization ID from the access denied error message is correct and the call is made in the region where the denial occurred. Ensure that the calling principal belongs to the same account or organization as the original denied request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
280 281 282 283 284 |
# File 'lib/aws-sdk-iamtoolbox/types.rb', line 280 class ResourceNotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |